@@ -19,7 +19,7 @@
 
 #include <gtk/gtk.h>
 #include <gconf/gconf-client.h>
-#include <libgswitchit/gswitchit_xkb_config.h>
+#include <libgswitchit/gswitchit_config.h>
 
 #define MAX_LOCAL_NAME_BUF_LENGTH 512
 
@@ -35,11 +35,12 @@ typedef const struct _GSwitchItPlugin
 typedef gboolean (*GSwitchItPluginInitFunc) (GSwitchItPluginContainer *
 					     pc);
 
-typedef void (*GSwitchItPluginGroupChangedFunc) (int newGroup);
+typedef void (*GSwitchItPluginGroupChangedFunc) (GtkWidget * notebook,
+						 int newGroup);
 
-typedef void (*GSwitchItPluginConfigChangedFunc) (const GSwitchItXkbConfig
+typedef void (*GSwitchItPluginConfigChangedFunc) (const GSwitchItKbdConfig
 						  * from,
-						  const GSwitchItXkbConfig
+						  const GSwitchItKbdConfig
 						  * to);
 
 typedef int (*GSwitchItPluginWindowCreatedFunc) (const Window win,
@@ -53,7 +54,7 @@ typedef GtkWidget *(*GSwitchItPluginDecorateWidget) (GtkWidget * widget,
 						     const gint group,
 						     const char
 						     *groupDescription,
-						     GSwitchItXkbConfig *
+						     GSwitchItKbdConfig *
 						     config);
 
 typedef
@@ -91,9 +92,6 @@ typedef struct _GSwitchItPlugin {
 
 } GSwitchItPlugin;
 
-typedef char
- GroupDescriptionsBuffer[XkbNumKbdGroups][MAX_LOCAL_NAME_BUF_LENGTH];
-
 /**
  * Functions accessible for plugins
  */
@@ -108,10 +106,8 @@ extern void GSwitchItPluginContainerReinitUi (GSwitchItPluginContainer *
 
 extern guint GSwitchItPluginGetNumGroups (GSwitchItPluginContainer * pc);
 
-extern void
-GSwitchItPluginLoadLocalizedGroupNames (GSwitchItPluginContainer * pc,
-					const
-					GroupDescriptionsBuffer **
-					outDescr);
+extern gchar
+    **GSwitchItPluginLoadLocalizedGroupNames (GSwitchItPluginContainer *
+					      pc);
 
 #endif
